import { __decorate } from "tslib";
import { property } from 'lit/decorators.js';
import style from './element.css';
import { IconButtonToggleBase } from '@material/mwc-icon-button-toggle/mwc-icon-button-toggle-base';
import { styles as mwcStyle } from '@material/mwc-icon-button/mwc-icon-button.css';
import { html } from 'lit';
import Icon from '@equinor/fusion-wc-icon';
import { ifDefined } from 'lit/directives/if-defined.js';
import { IconButtonToggleColor, IconButtonToggleSize } from './types';
import { classMap } from 'lit/directives/class-map.js';
// Persist element
Icon;
export class IconButtonToggleElement extends IconButtonToggleBase {
    constructor() {
        super(...arguments);
        this.onColor = IconButtonToggleColor.Primary;
        this.offColor = IconButtonToggleColor.Primary;
        this.size = IconButtonToggleSize.Medium;
        /* override on/off icons for the icon type change */
        this.onIcon = '';
        this.offIcon = '';
    }
    /**
     * override rendering of the ripple
     * @returns the ripple for setting up 'unbounded' as an additional property
     */
    renderRipple() {
        return this.shouldRenderRipple
            ? html ` <mwc-ripple .disabled="${this.disabled}" .unbounded="${this.rounded}"> </mwc-ripple>`
            : '';
    }
    /**
     * override render of the icon button
     * @returns full render of IconButtonBase with fwc-icon used instead of alredy used material icon
     */
    render() {
        /** @classMap */
        const classes = {
            'mdc-icon-button--on': this.on,
        };
        const hasToggledAriaLabel = this.ariaLabelOn !== undefined && this.ariaLabelOff !== undefined;
        const ariaPressedValue = hasToggledAriaLabel ? undefined : this.on;
        const ariaLabelValue = hasToggledAriaLabel ? (this.on ? this.ariaLabelOn : this.ariaLabelOff) : this.ariaLabel;
        return html `<button
      class="mdc-icon-button mdc-icon-button--display-flex ${classMap(classes)}"
      aria-pressed="${ifDefined(ariaPressedValue)}"
      aria-label="${ifDefined(ariaLabelValue)}"
      @click="${this.handleClick}"
      ?disabled="${this.disabled}"
      @focus="${this.handleRippleFocus}"
      @blur="${this.handleRippleBlur}"
      @mousedown="${this.handleRippleMouseDown}"
      @mouseenter="${this.handleRippleMouseEnter}"
      @mouseleave="${this.handleRippleMouseLeave}"
      @touchstart="${this.handleRippleTouchStart}"
      @touchend="${this.handleRippleDeactivate}"
      @touchcancel="${this.handleRippleDeactivate}"
    >
      ${this.renderRipple()}
      <span class="mdc-icon-button__icon"
        ><slot name="offIcon"><fwc-icon .icon=${this.offIcon} /></span
      >
      <span class="mdc-icon-button__icon mdc-icon-button__icon--on"
        ><slot name="onIcon"><fwc-icon .icon=${this.onIcon} /></span
      >
    </button>`;
    }
}
/* styles object css */
IconButtonToggleElement.styles = [style, mwcStyle];
__decorate([
    property({ type: String })
], IconButtonToggleElement.prototype, "onColor", void 0);
__decorate([
    property({ type: String })
], IconButtonToggleElement.prototype, "offColor", void 0);
__decorate([
    property({ type: String })
], IconButtonToggleElement.prototype, "size", void 0);
__decorate([
    property({ type: Boolean })
], IconButtonToggleElement.prototype, "rounded", void 0);
export default IconButtonToggleElement;
//# sourceMappingURL=element.js.map